==> flame-0.19.1-beta.tar.gz: doc/README.md <==
# Getting Started!

## About Flame

Flame is a modular Flutter game engine that provides a complete set of out-of-the-way solutions for games, taking advantage of the powerful infrastructure provided by Flutter but simplifying the code you need to build your projects.

It empowers you with a simple yet effective game loop implementation, and all the surrounding utilities you might need to use in a game: images, sprites, sprite sheets, animations, audio, input, components/object system, et cetera.

You can pick and choose whichever parts you want, as they are all somewhat independent and modular.

We also support easy-to-use integrations with famous third parties and tools, like Riveapp, box2d, tiled, Google Play Games, gamepad support and more.

The engine and ecosystem is being constantly improved by the community, so please feel free to reach out, open issues, PRs, make suggestions. Give us a star if you feel like it :)

## Installation

Put the pub package as your dependency by dropping the following in your `pubspec.yaml`:

## Getting started

Check out the [awesome flame repository](https://github.com/flame-engine/awesome-flame#articles--tutorials), there is quite a lot of good tutorials and articles to get you started with Flame.


```yaml
dependencies:
  flame: ^0.19.0
```

And start using it!

## Topics

 * Core Concepts
   - [Structure](structure.md)
   - [Game Loop](game.md)
   - [Components](components.md)
   - [Input](input.md)
 * Audio
   - [General Audio](audio.md)
   - [Looping Background Music](bgm.md)
 * Rendering
   - [Images, Sprites and Animations](images.md)
   - [Text Rendering](text.md)
   - [Colors and the Palette](palette.md)
   - [Particles](particles.md)
 * Other Modules
   - [Util](util.md)
   - [Gamepad](gamepad.md)
   - [Widgets](widgets.md)
   - [Box2D](box2d.md)
   - [Tiled](tiled.md)
   - [Debugging](debug.md)
   - [Splash screen](splash_screen.md)

==> flame-0.29.1-beta.tar.gz: doc/README.md <==
# Getting Started!

## About Flame

Flame is a modular Flutter game engine that provides a complete set of out-of-the-way solutions for games, taking advantage of the powerful infrastructure provided by Flutter but simplifying the code you need to build your projects.

It empowers you with a simple yet effective game loop implementation, and all the surrounding utilities you might need to use in a game: images, sprites, sprite sheets, animations, audio, input, components/object system, et cetera.

You can pick and choose whichever parts you want, as they are all somewhat independent and modular.

We also support easy-to-use integrations with famous third parties and tools, like Riveapp, box2d, tiled, Google Play Games, gamepad support and more.

The engine and ecosystem is being constantly improved by the community, so please feel free to reach out, open issues, PRs and make suggestions. Give us a star if you want to help give the engine exposure and grow the community.

## Installation

Put the pub package as your dependency by dropping the following in your `pubspec.yaml`:

```yaml
dependencies:
  flame: ^0.29.1-beta
```

And start using it!

## Getting started

Check out the [awesome flame repository](https://github.com/flame-engine/awesome-flame#articles--tutorials), there is quite a lot of good tutorials and articles to get you started with Flame.

## Topics

 * Core Concepts
   - [Structure](structure.md)
   - [Game Loop](game.md)
   - [Components](components.md)
   - [Input](input.md)
   - [Platforms](platforms.md)
 * Audio
   - [General Audio](audio.md)
   - [Looping Background Music](bgm.md)
 * Rendering
   - [Images, Sprites and Animations](images.md)
   - [Text Rendering](text.md)
   - [Colors and the Palette](palette.md)
   - [Particles](particles.md)
   - [Layers](layers.md)
 * Other Modules
   - [Util](util.md)
   - [Gamepad](gamepad.md)
   - [Widgets](widgets.md)
   - [Box2D](box2d.md)
   - [Tiled](tiled.md)
   - [Debugging](debug.md)
   - [Splash screen](splash_screen.md)
